from md_translate.arguments_processor import settings
from md_translate.exceptions import NoApiKeyFileError
from md_translate.files_worker import FilesWorker


class App:
    def __init__(self):
        self.settings = settings
        self.__validate_setup()

    def __validate_setup(self):
        try:
            self.settings.validate_arguments()
        except NoApiKeyFileError:
            print('API_KEY file in location "{}" not found'.format(self.settings.api_key))
            print('Provide API_KEY file path or create it, if not exist')
            print()
            self.settings.arg_parser.print_help()
            exit(1)

    def process(self):
        FilesWorker(self.settings.path).process()


if __name__ == "__main__":
    app = App()
    app.process()



import requests

from md_translate.arguments_processor import settings


def get_translator_by_name(name):
    if name == 'Yandex':
        return YandexTranslator
    elif name == 'Google':
        return GoogleTranslator


class Translator:
    BASE_API_URL = None

    def request_translation(self, string_to_translate):
        response = self.request_for_translation(string_to_translate)
        if response.ok:
            translated_data = self.process_response(response)
            return '\n'.join(translated_data)
        else:
            raise requests.exceptions.ConnectionError('Something web wrong with translation requesting.')

    def request_for_translation(self, string_to_translate):
        raise NotImplementedError()

    def process_response(self, response):
        raise NotImplementedError()


class YandexTranslator(Translator):
    BASE_API_URL = 'https://translate.yandex.net/api/v1.5/tr.json/translate'

    def request_for_translation(self, string_to_translate):
        params = {'key': settings.api_key_value,
                  'lang': '-'.join([settings.source_lang, settings.target_lang]),
                  }
        data = {'text': string_to_translate}
        return requests.post(self.BASE_API_URL, params=params,
                             data=data
                             )

    def process_response(self, response):
        return response.json()['text']


class GoogleTranslator(Translator):
    BASE_API_URL = 'https://translation.googleapis.com/language/translate/v2'

    def request_for_translation(self, string_to_translate):
        headers = {'Authorization': 'Bearer "{}"'.format(settings.api_key_value)}
        data = {'q': string_to_translate,
                'source': settings.source_lang,
                'target': settings.target_lang,
                'format': 'text'}
        return requests.post(self.BASE_API_URL, headers=headers, data=data)

    def process_response(self, response):
        return response.json()['data']['translations'][0]['translatedText']



import re


class LineProcessor:
    code_mark = '```'
    paragraph_regexp = re.compile(r'^[a-zA-Z]+.*')

    def __init__(self, line):
        """

        :param line: str
        """
        self._line = line

    def is_code_block_border(self):
        if self._line == self.code_mark:
            return True
        return self._line.startswith(self.code_mark) and not self._line.endswith(self.code_mark)

    def line_can_be_translated(self):
        return not self.__is_single_code_line() and self.__is_untranslated_paragraph()

    def __is_untranslated_paragraph(self):
        return self.paragraph_regexp.match(self._line)

    def __is_single_code_line(self):
        return self._line.startswith(self.code_mark) and self._line.endswith(self.code_mark) and len(self._line) > 3



import argparse
import os
import pathlib

from md_translate.exceptions import NoApiKeyFileError


class ArgumentsProcessor:
    APPLICATION_DESCRIPTION = 'Application allows to translate markdown files.\n' \
                              'See README.md for more information'

    TRANSLATOR_API_KEY_FILENAME = '.md_translate_api_key'

    def __init__(self):
        self.arg_parser = argparse.ArgumentParser(self.APPLICATION_DESCRIPTION)
        self.parser = self.process_arguments()
        self.path = self.parser.path
        self.api_key = self.parser.api_key
        self.service = self.parser.service
        self.source_lang = self.parser.source_lang
        self.target_lang = self.parser.target_lang

    @property
    def api_key_value(self):
        with open(self.api_key) as api_key_file:
            return api_key_file.read()

    def process_arguments(self):
        self.arg_parser.add_argument(
            'path',
            help='Path to folder to process.',
            type=pathlib.Path)
        self.arg_parser.add_argument(
            '-k', '--api_key',
            help='Path to Translation Service API key file',
            default=os.path.join(str(pathlib.Path.home()), self.TRANSLATOR_API_KEY_FILENAME),
            type=pathlib.Path)
        self.arg_parser.add_argument(
            '-s', '--service',
            help='Translating service',
            default='Yandex', choices=('Yandex',)
        )
        self.arg_parser.add_argument(
            '-S', '--source_lang',
            help='Source language',
            default='en'
        )
        self.arg_parser.add_argument(
            '-T', '--target_lang',
            help='Target language',
            default='ru'
        )
        return self.arg_parser.parse_args()

    def validate_arguments(self):
        if not os.path.exists(self.api_key):
            raise NoApiKeyFileError


settings = ArgumentsProcessor()



import setuptools


def get_version():
    with open("VERSION", "r") as fh:
        version = fh.read()
    return version


def get_long_description():
    with open("README.md", "r") as fh:
        long_description = fh.read()
    return long_description


setuptools.setup(
    # Common data
    name="md_translate",
    version=get_version(),
    author="Ilya Chichak",
    author_email="ilyachch@gmail.com",
    description="CLI tool to translate markdown files",
    # Meta
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    license="MIT License",
    url="https://github.com/ilyachch/md_docs-trans-app",
    # Technical data
    python_requires=">=3.4",
    packages=setuptools.find_packages(exclude=['tests*', ]),
    install_requires=[
        "requests",
    ],
    extras_require={
        'dev': [
            'twine',
            'wheel',
            'setuptools',
            'bumpversion',
        ]
    },
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
        "Operating System :: Microsoft :: Windows",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Documentation",
        "Topic :: Utilities",
    ],
    entry_points={
        'console_scripts': ['gs_extensions=gs_extensions.app:main'],
    }
)



import os

from md_translate.exceptions import DirectoryNotFoundException
from md_translate.file_translator import FileTranslator


class FilesWorker:
    def __init__(self, folder_to_process):
        self.__folder_to_process = folder_to_process
        self.__validate_folder()
        self.md_files_list = self.__get_md_files_list()

    def __validate_folder(self):
        if not os.path.exists(self.__folder_to_process):
            raise DirectoryNotFoundException('No such folder: {}!'.format(self.__folder_to_process))
        if not os.path.isdir(self.__folder_to_process):
            raise NotADirectoryError('With selected path provided a file, not a folder!')

    def __get_md_files_list(self):
        md_files_list = []
        for link in os.listdir(self.__folder_to_process):
            if link.endswith('.md'):
                md_files_list.append(link)
        if len(md_files_list) == 0:
            raise FileNotFoundError('There are no MD files found with provided path!')
        return md_files_list

    def process(self):
        for file_name in self.md_files_list:
            with FileTranslator(os.path.join(self.__folder_to_process, file_name)) as processing_file:
                processing_file.translate()
            print('Processed: {file_name}'.format(file_name=file_name))
